package
Version:
v0.3.2
Opens a new window with list of versions in this module.
Published: Apr 5, 2025
License: Unlicense
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type ListPool[I any] struct {
}
can't be used concurrently, use sync.Pool instead.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.